import { hierarchy, schemeCategory10 } from 'd3';
export const eventSequences = (selection, props) => {
  const {
    data,
    regex,
    margin,
    spacing,
    length,
    highlightedSequenceId,
    highlightedSequence,
    highlightSequence,
    handleSequence,
    handleEvent,
    selectEvent,
    selectedEvents,
  } = props;
  
  let colorIndex = 0;
  selection.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  // Selection & Enter for Sequences
  const sequences = selection
    .selectAll('.sequences')
    .data(data, (d,i) => d[0].data.id);
  
  const sequencesEnter = sequences
    .enter().append('g')
      .attr('foo', (d) =>
            (checkRegex(regex, d[0].data.data.gui, handleSequence))
            ? '#42f462'
            : 'gray')
      .attr('class', 'sequences')
      .attr('transform', (d,i) => 
            `translate(0, ${(length + spacing.bottom) * i})`)
      .on('click', (d,i) => highlightSequence(d,i));
  
  sequencesEnter.append('text')
    .attr('x', (d) => (length + spacing.bottom) * (d.length-1))
    .attr('y', 0)
    .attr('dy', '0.85em')
    .text((d) => d[0].data.data.count);
  
  sequences.exit().remove();
  
  
  // Highlight Selected Sequence
  const sequenceHighlight = selection
    .selectAll('.highlight')
    .data([highlightedSequenceId], (d) => d);
  
  const sequenceHighlightEnter = sequenceHighlight
    .enter().append('rect')
      .attr('class', 'highlight')
      .attr('fill', 'none')
      .attr('stroke', 'yellow')
      .attr('stroke-width', '5px')
      .attr('height', length + spacing.bottom)
    	.attr('width', (highlightedSequence)
                      ? (spacing.right + length) * highlightedSequence.length
                      : 0)
      .attr('transform', (highlightedSequenceId)
            							? `translate(0, 
														${highlightedSequenceId 
            								* (length + spacing.bottom)
            								- (spacing.bottom / 2)})`
                          : null);
  sequenceHighlightEnter.exit().remove();
  sequenceHighlight.exit().remove();
      
  
  // Selection & Enter for Events
  let row_i;
  const events = sequencesEnter.selectAll('.events').data((d) => d.slice(1));
  const eventsEnter = events
    .enter().append('rect')
      .attr('class', 'events')
      .attr('width', length)
      .attr('height', length)
      .attr('stroke', 'none')
      .attr('stroke-width', '0.3px')
      .attr('x', (d, i) => (spacing.right + length) * i)
  	.merge(events)
  		.attr('fill', (d,i) => {
        if(i === 0) row_i = d.data.data.id;
        const { id, depth } = d.data.data
        if(selectedEvents[id] && selectedEvents[id][depth] === true) {
        	return schemeCategory10[row_i % 10];
        }
        if(checkRegex(regex, d.data.data.event, handleEvent))
          return '#42f462';
        return '#606060';
      });
  
  events.exit().remove();
}


function checkRegex(regex, data, updateMeta) {
  // const properties = ['N', 'CN', 'CT'];
  // for(let prop of properties) 
  // {
  //   if(data.hasOwnProperty(prop) && regex) {
  //     if(regex.exec(data[prop])) {
  //       updateMeta(true);
  //       return true;
  //     }
  //   }
  // }
  
  if(regex && regex.exec(data)) {
    updateMeta(true);
    return true;
  }
  
  updateMeta(false);
  return false;
}



